@@ -1,38 +1,38 @@
-/* 
- * RTjpeg.c (C) Justin Schoeman 1998 (justin@suntiger.ee.up.ac.za)
- *  
- * With modifications by:
- * (c) 1998, 1999 by Joerg Walter <trouble@moes.pmnet.uni-oldenburg.de>
- * and
- * (c) 1999 by Wim Taymans <wim.taymans@tvd.be>
- * 
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- */
+/*******************************************************************************
+ RTjpeg.c
 
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
 
-#include "config.h"
-#include <stdio.h>
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2010 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
 #include <stdlib.h>
-#include <string.h>
+#include <strings.h>
 #define __RTJPEG_INTERNAL__
 #include "RTjpeg.h"
-
 #ifdef MMX
 #include "mmx.h"
 #endif
 
+#define LOG_DOMAIN "rtjpeg"
+
 static const unsigned char RTjpeg_ZZ[64]={
 0,
 8, 1,
@@ -83,7 +83,7 @@ static const unsigned char RTjpeg_chrom_quant_tbl[64] = {
     99,  99,  99,  99,  99,  99,  99,  99
  };
  
-int RTjpeg_b2s(int16_t *data, int8_t *strm, uint8_t bt8)
+static int RTjpeg_b2s(int16_t *data, int8_t *strm, uint8_t bt8)
 {
  register int ci, co=1, tmp;
  register int16_t ZZvalue;
@@ -131,7 +131,7 @@ int RTjpeg_b2s(int16_t *data, int8_t *strm, uint8_t bt8)
  return (int)co;
 }
 
-int RTjpeg_s2b(int16_t *data, int8_t *strm, uint8_t bt8, uint32_t *qtbl)
+static int RTjpeg_s2b(int16_t *data, int8_t *strm, uint8_t bt8, uint32_t *qtbl)
 {
  int ci=1, co=1, tmp;
  register int i;
@@ -175,8 +175,8 @@ void RTjpeg_quant_init(RTjpeg_t *rtj)
  for(i=0; i<64; i++)qtbl[i]=(int16_t)rtj->cqt[i];
 }
 
-static mmx_t RTjpeg_ones=(mmx_t)0x0001000100010001LL;
-static mmx_t RTjpeg_half=(mmx_t)0x7fff7fff7fff7fffLL;
+static mmx_t RTjpeg_ones=(mmx_t)(uint64_t)0x0001000100010001LL;
+static mmx_t RTjpeg_half=(mmx_t)(uint64_t)0x7fff7fff7fff7fffLL;
 
 void RTjpeg_quant(int16_t *block, int32_t *qtbl)
 {
@@ -215,11 +215,11 @@ void RTjpeg_quant(int16_t *block, int32_t *qtbl)
  }
 }
 #else
-void RTjpeg_quant_init(RTjpeg_t *rtj)
+static void RTjpeg_quant_init(RTjpeg_t *rtj)
 {
 }
 
-void RTjpeg_quant(int16_t *block, int32_t *qtbl)
+static void RTjpeg_quant(int16_t *block, int32_t *qtbl)
 {
  int i;
  
@@ -233,11 +233,11 @@ void RTjpeg_quant(int16_t *block, int32_t *qtbl)
  * Perform the forward DCT on one block of samples.
  */
 #ifdef MMX
-static mmx_t RTjpeg_C4   =(mmx_t)0x2D412D412D412D41LL;
-static mmx_t RTjpeg_C6   =(mmx_t)0x187E187E187E187ELL;
-static mmx_t RTjpeg_C2mC6=(mmx_t)0x22A322A322A322A3LL;
-static mmx_t RTjpeg_C2pC6=(mmx_t)0x539F539F539F539FLL;
-static mmx_t RTjpeg_zero =(mmx_t)0x0000000000000000LL;
+static mmx_t RTjpeg_C4   =(mmx_t)(uint64_t)0x2D412D412D412D41LL;
+static mmx_t RTjpeg_C6   =(mmx_t)(uint64_t)0x187E187E187E187ELL;
+static mmx_t RTjpeg_C2mC6=(mmx_t)(uint64_t)0x22A322A322A322A3LL;
+static mmx_t RTjpeg_C2pC6=(mmx_t)(uint64_t)0x539F539F539F539FLL;
+static mmx_t RTjpeg_zero =(mmx_t)(uint64_t)0x0000000000000000LL;
 
 #else
 
@@ -251,7 +251,7 @@ static mmx_t RTjpeg_zero =(mmx_t)0x0000000000000000LL;
 #define D_MULTIPLY(var,const)  ((int32_t) ((var) * (const)))
 #endif
 
-void RTjpeg_dct_init(RTjpeg_t *rtj)
+static void RTjpeg_dct_init(RTjpeg_t *rtj)
 {
  int i;
  
@@ -262,7 +262,7 @@ void RTjpeg_dct_init(RTjpeg_t *rtj)
  }
 }
 
-void RTjpeg_dctY(RTjpeg_t *rtj, uint8_t *idata, int rskip)
+static void RTjpeg_dctY(RTjpeg_t *rtj, uint8_t *idata, int rskip)
 {
 #ifndef MMX
   int32_t tmp0, tmp1, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7;
@@ -1182,7 +1182,7 @@ void RTjpeg_dctY(RTjpeg_t *rtj, uint8_t *idata, int rskip)
 #define RL(x) ((x)>235) ? 235 : (((x)<16) ? 16 : (x))
 #define MULTIPLY(var,const)  (((int32_t) ((var) * (const)) + 128)>>8)
 
-void RTjpeg_idct_init(RTjpeg_t *rtj)
+static void RTjpeg_idct_init(RTjpeg_t *rtj)
 {
  int i;
  
@@ -1193,15 +1193,15 @@ void RTjpeg_idct_init(RTjpeg_t *rtj)
  }
 }
 
-void RTjpeg_idct(RTjpeg_t *rtj, uint8_t *odata, int16_t *data, int rskip)
+static void RTjpeg_idct(RTjpeg_t *rtj, uint8_t *odata, int16_t *data, int rskip)
 {
 #ifdef MMX
 
-static mmx_t fix_141		= (mmx_t)0x5a825a825a825a82LL;
-static mmx_t fix_184n261	= (mmx_t)0xcf04cf04cf04cf04LL;
-static mmx_t fix_184		= (mmx_t)0x7641764176417641LL;
-static mmx_t fix_n184		= (mmx_t)0x896f896f896f896fLL;
-static mmx_t fix_108n184	= (mmx_t)0xcf04cf04cf04cf04LL;
+static mmx_t fix_141		= (mmx_t)(uint64_t)0x5a825a825a825a82LL;
+static mmx_t fix_184n261	= (mmx_t)(uint64_t)0xcf04cf04cf04cf04LL;
+static mmx_t fix_184		= (mmx_t)(uint64_t)0x7641764176417641LL;
+static mmx_t fix_n184		= (mmx_t)(uint64_t)0x896f896f896f896fLL;
+static mmx_t fix_108n184	= (mmx_t)(uint64_t)0xcf04cf04cf04cf04LL;
 
   mmx_t *wsptr = (mmx_t *)rtj->ws;
   register mmx_t *dataptr = (mmx_t *)odata;
@@ -2132,9 +2132,7 @@ static mmx_t fix_108n184	= (mmx_t)0xcf04cf04cf04cf04LL;
 
 	/*
    movq_r2m(mm4, *dummy);
-	fprintf(stderr, "3-4 %016llx\n", dummy);
    movq_r2m(mm4, *dummy);
-	fprintf(stderr, "3+4 %016llx\n", dummy);
 	*/
 	
 
@@ -2320,7 +2318,7 @@ This file contains most of the initialisation and control functions
 
 */
 
-inline void RTjpeg_calc_tbls(RTjpeg_t *rtj)
+static inline void RTjpeg_calc_tbls(RTjpeg_t *rtj)
 {
  int i;
  uint64_t qual;
@@ -2424,7 +2422,7 @@ int RTjpeg_set_size(RTjpeg_t *rtj, int *w, int *h)
   rtj->old=(int16_t *)(tmp<<5);
   if(!rtj->old)
   {
-   fprintf(stderr, "RTjpeg: Could not allocate memory\n");
+   lqt_log(NULL, LQT_LOG_ERROR, LOG_DOMAIN, "RTjpeg: Could not allocate memory");
    return -1;
   }
   bzero(rtj->old, ((4*rtj->width*rtj->height)));
@@ -2445,8 +2443,8 @@ int RTjpeg_set_intra(RTjpeg_t *rtj, int *key, int *lm, int *cm)
  if (*cm < 0) *cm = 0;
  if (*cm > 16) *cm = 16;
 #ifdef MMX
- rtj->lmask=(mmx_t)(((unsigned long long)(*lm)<<48)|((unsigned long long)(*lm)<<32)|((unsigned long long)(*lm)<<16)|(unsigned long long)(*lm));
- rtj->cmask=(mmx_t)(((unsigned long long)(*cm)<<48)|((unsigned long long)(*cm)<<32)|((unsigned long long)(*cm)<<16)|(unsigned long long)(*cm));
+ rtj->lmask=(mmx_t)(((uint64_t)(*lm)<<48)|((uint64_t)(*lm)<<32)|((uint64_t)(*lm)<<16)|(uint64_t)(*lm));
+ rtj->cmask=(mmx_t)(((uint64_t)(*cm)<<48)|((uint64_t)(*cm)<<32)|((uint64_t)(*cm)<<16)|(uint64_t)(*cm));
 #else
  rtj->lmask=*lm;
  rtj->cmask=*cm;
@@ -2460,7 +2458,7 @@ int RTjpeg_set_intra(RTjpeg_t *rtj, int *key, int *lm, int *cm)
  rtj->old=(int16_t *)(tmp<<5);
  if (!rtj->old)
  {
-  fprintf(stderr, "RTjpeg: Could not allocate memory\n");
+  lqt_log(NULL, LQT_LOG_ERROR, LOG_DOMAIN, "RTjpeg: Could not allocate memory");
   return -1;
  }
  bzero(rtj->old, ((4*rtj->width*rtj->height)));
@@ -2588,7 +2586,7 @@ static inline int RTjpeg_compressYUV422(RTjpeg_t *rtj, uint8_t *sp, uint8_t **pl
  return (sp-sb);
 }
 
-inline int RTjpeg_compress8(RTjpeg_t *rtj, uint8_t *sp, uint8_t **planes)
+static inline int RTjpeg_compress8(RTjpeg_t *rtj, uint8_t *sp, uint8_t **planes)
 {
  register uint8_t * bp = planes[0];
  uint8_t * sb;
@@ -2767,7 +2765,7 @@ int RTjpeg_bcomp(int16_t *rblock, int16_t *old, mmx_t *mask)
  mmx_t *mold=(mmx_t *)old;
  mmx_t *mblock=(mmx_t *)rblock;
  volatile mmx_t result;
- static mmx_t neg=(mmx_t)0xffffffffffffffffULL;
+ static mmx_t neg=(mmx_t)(uint64_t)0xffffffffffffffffULL;
  
  movq_m2r(*mask, mm7);
  movq_m2r(neg, mm6);
@@ -2805,7 +2803,7 @@ int RTjpeg_bcomp(int16_t *rblock, int16_t *old, mmx_t *mask)
 }
 
 #else
-int RTjpeg_bcomp(int16_t *rblock, int16_t *old, uint16_t *mask)
+static int RTjpeg_bcomp(int16_t *rblock, int16_t *old, uint16_t *mask)
 {
  int i;
 
@@ -2819,7 +2817,7 @@ int RTjpeg_bcomp(int16_t *rblock, int16_t *old, uint16_t *mask)
 }
 #endif
 
-int RTjpeg_mcompressYUV420(RTjpeg_t *rtj, uint8_t *sp, unsigned char **planes)
+static int RTjpeg_mcompressYUV420(RTjpeg_t *rtj, uint8_t *sp, unsigned char **planes)
 {
  uint8_t * sb;
  int16_t *block;
@@ -2902,7 +2900,7 @@ int RTjpeg_mcompressYUV420(RTjpeg_t *rtj, uint8_t *sp, unsigned char **planes)
 }
 
 
-int RTjpeg_mcompressYUV422(RTjpeg_t *rtj, uint8_t *sp, unsigned char **planes)
+static int RTjpeg_mcompressYUV422(RTjpeg_t *rtj, uint8_t *sp, unsigned char **planes)
 {
  uint8_t * sb;
  int16_t *block;
@@ -2968,7 +2966,7 @@ int RTjpeg_mcompressYUV422(RTjpeg_t *rtj, uint8_t *sp, unsigned char **planes)
  return (sp-sb);
 }
 
-int RTjpeg_mcompress8(RTjpeg_t *rtj, uint8_t *sp, unsigned char **planes)
+static int RTjpeg_mcompress8(RTjpeg_t *rtj, uint8_t *sp, unsigned char **planes)
 {
  register uint8_t * bp = planes[0];
  uint8_t * sb;
@@ -2997,8 +2995,8 @@ int RTjpeg_mcompress8(RTjpeg_t *rtj, uint8_t *sp, unsigned char **planes)
 #endif
  return (sp-sb);
 }
-
-int RTjpeg_nullcompressYUV420(RTjpeg_t *rtj, uint8_t *sp)
+#if 0
+static int RTjpeg_nullcompressYUV420(RTjpeg_t *rtj, uint8_t *sp)
 {
  uint8_t * sb;
  register int i, j, k;
@@ -3015,7 +3013,7 @@ int RTjpeg_nullcompressYUV420(RTjpeg_t *rtj, uint8_t *sp)
  return (sp-sb);
 }
 
-int RTjpeg_nullcompressYUV422(RTjpeg_t *rtj, uint8_t *sp)
+static int RTjpeg_nullcompressYUV422(RTjpeg_t *rtj, uint8_t *sp)
 {
  uint8_t * sb;
  register int i, j, k;
@@ -3031,8 +3029,7 @@ int RTjpeg_nullcompressYUV422(RTjpeg_t *rtj, uint8_t *sp)
  }
  return (sp-sb);
 }
-
-int RTjpeg_nullcompress8(RTjpeg_t *rtj, uint8_t *sp)
+static int RTjpeg_nullcompress8(RTjpeg_t *rtj, uint8_t *sp)
 {
  uint8_t * sb;
  int i, j;
@@ -3047,6 +3044,7 @@ int RTjpeg_nullcompress8(RTjpeg_t *rtj, uint8_t *sp)
  }
  return (sp-sb);
 }
+#endif
 
 #define KcrR 76284
 #define KcrG 53281
@@ -3502,8 +3500,8 @@ int RTjpeg_compress(RTjpeg_t *rtj, uint8_t *sp, uint8_t **planes)
  fh->quality = rtj->Q;
  return ds;
 }
-
-int RTjpeg_nullcompress(RTjpeg_t *rtj, int8_t *sp)
+#if 0
+static int RTjpeg_nullcompress(RTjpeg_t *rtj, int8_t *sp)
 {
  RTjpeg_frameheader * fh = (RTjpeg_frameheader *)sp;
  int ds = 0;
@@ -3540,7 +3538,7 @@ int RTjpeg_nullcompress(RTjpeg_t *rtj, int8_t *sp)
  fh->quality = rtj->Q;
  return ds;
 }
-
+#endif
 void RTjpeg_decompress(RTjpeg_t *rtj, uint8_t *sp, uint8_t **planes)
 {
  RTjpeg_frameheader * fh = (RTjpeg_frameheader *)sp;
