@@ -1,35 +1,45 @@
-/* 
- * RTjpeg (C) Justin Schoeman 1998 (justin@suntiger.ee.up.ac.za)
- *  
- * With modifications by:
- * (c) 1998, 1999 by Joerg Walter <trouble@moes.pmnet.uni-oldenburg.de>
- * and
- * (c) 1999 by Wim Taymans <wim.taymans@tvd.be>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- */
+/*******************************************************************************
+ RTjpeg.h
+
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2010 Members of the libquicktime project.
+
+ RTjpeg:
+ 
+ Copyright (C) Justin Schoeman 1998 <justin@suntiger.ee.up.ac.za>
+
+ With modifications by:
+ 
+ Copyright (C) 1998, 1999 by Joerg Walter <trouble@moes.pmnet.uni-oldenburg.de>
+ Copyright (C) 1999 by Wim Taymans <wim.taymans@tvd.be>
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+/*
+
+ Added support for video, which is no multiple of 16.
+ 
+ - Burkhard Plaum
+
+*/
 
-#ifdef HAVE_STDINT_H
-#ifndef _STDINT_H
-#include <stdint.h>
-#endif
-#else
-#ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
-#endif
-#endif
 
 #ifdef __RTJPEG_INTERNAL__
 
