@@ -1,7 +1,29 @@
+/*******************************************************************************
+ atom.c
+
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2010 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
 #include <ctype.h>
-#include <stdio.h>
-#include <funcprotos.h>
-#include <quicktime/quicktime.h>
 
 static int read_type(uint8_t *data, uint8_t *type)
 {
@@ -10,7 +32,6 @@ static int read_type(uint8_t *data, uint8_t *type)
 	type[2] = data[6];
 	type[3] = data[7];
 
-/*printf("%c%c%c%c ", type[0], type[1], type[2], type[3]); */
 /* need this for quicktime_check_sig */
 	if(isalpha(type[0]) && isalpha(type[1]) && isalpha(type[2]) && isalpha(type[3]))
 	return 0;
@@ -101,13 +122,6 @@ int quicktime_atom_read_header(quicktime_t *file, quicktime_atom_t *atom)
 		result = read_type(header, atom->type);
 		atom->size = read_size(header);
 		atom->end = atom->start + atom->size;
-/*
- * printf("quicktime_atom_read_header 1 %c%c%c%c start %llx size %llx end %llx ftell %llx %llx\n", 
- * 	atom->type[0], atom->type[1], atom->type[2], atom->type[3],
- * 	atom->start, atom->size, atom->end,
- * 	file->file_position,
- * 	(int64_t)ftello(file->stream));
- */
 
 /* Skip placeholder atom */
 		if(quicktime_match_32(atom->type, "wide"))
@@ -131,12 +145,6 @@ int quicktime_atom_read_header(quicktime_t *file, quicktime_atom_t *atom)
 			if(!quicktime_read_data(file, header, HEADER_LENGTH)) return 1;
 			atom->size = read_size64(header);
 			atom->end = atom->start + atom->size;
-/*
- * printf("quicktime_atom_read_header 2 %c%c%c%c start %llx size %llx end %llx ftell %llx\n", 
- * 	atom->type[0], atom->type[1], atom->type[2], atom->type[3],
- * 	atom->start, atom->size, atom->end,
- * 	file->file_position);
- */
 		}
 	}
 
@@ -199,7 +207,6 @@ void quicktime_atom_write_footer(quicktime_t *file, quicktime_atom_t *atom)
 		if(atom->use_64)
 		{
 			quicktime_set_position(file, atom->start + 8);
-//printf("quicktime_atom_write_footer %llx %llx %llx %llx\n", file->total_length, file->file_position, atom->start, atom->end);
 			quicktime_write_int64(file, atom->end - atom->start);
 		}
 		else
