@@ -5,7 +5,7 @@
  http://libquicktime.sourceforge.net
 
  Copyright (C) 2002 Heroine Virtual Ltd.
- Copyright (C) 2002-2007 Members of the libquicktime project.
+ Copyright (C) 2002-2010 Members of the libquicktime project.
 
  This library is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the Free
@@ -108,7 +108,7 @@ void quicktime_avih_init(quicktime_avih_t *avih, quicktime_t * file)
   if(file->total_vtracks)
     avih->dwMicroSecPerFrame = (uint32_t)(1000000 / quicktime_frame_rate(file, 0));
   avih->dwFlags = AVI_HASINDEX | AVI_ISINTERLEAVED;
-  avih->dwStreams = file->moov.total_tracks;
+  avih->dwStreams = file->total_atracks + file->total_vtracks;
   //  avih->dwSuggestedBufferSize = 1024 * 1024;
 
   if(file->total_vtracks)
