@@ -1,16 +1,38 @@
-#include <funcprotos.h>
-#include <quicktime/quicktime.h>
+/*******************************************************************************
+ avi_hdrl.c
 
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
 
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2010 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
 
 void quicktime_delete_hdrl(quicktime_t *file, quicktime_hdrl_t *hdrl)
-{
-	int i;
-	for(i = 0; i < file->moov.total_tracks; i++)
-	{
-		quicktime_delete_strl(hdrl->strl[i]);
-	}
-}
+  {
+  int i;
+  for(i = 0; i < file->moov.total_tracks; i++)
+    {
+    if(hdrl->strl[i])
+      quicktime_delete_strl(hdrl->strl[i]);
+    }
+  }
 
 
 void quicktime_read_hdrl(quicktime_t *file, 
@@ -21,7 +43,6 @@ void quicktime_read_hdrl(quicktime_t *file,
 	uint8_t data[4];
 	int current_track = 0;
 
-//printf("quicktime_read_hdrl 1\n");
 	do
 	{
 		quicktime_atom_read_header(file, &leaf_atom);
@@ -80,6 +101,7 @@ void quicktime_init_hdrl(quicktime_t *file, quicktime_hdrl_t *hdrl)
     quicktime_strl_t *strl = 
       hdrl->strl[current_track++] = 
       quicktime_new_strl();
+    trak->tkhd.track_id = current_track;
     quicktime_init_strl(file, 
                         0, 
                         video_map, 
@@ -94,6 +116,7 @@ void quicktime_init_hdrl(quicktime_t *file, quicktime_hdrl_t *hdrl)
     quicktime_strl_t *strl = 
       hdrl->strl[current_track++] = 
       quicktime_new_strl();
+    trak->tkhd.track_id = current_track;
     quicktime_init_strl(file, 
                         audio_map,
                         0,
@@ -101,12 +124,6 @@ void quicktime_init_hdrl(quicktime_t *file, quicktime_hdrl_t *hdrl)
                         strl);
     }
     
-  /*
-   * for(i = 0; i < file->moov.total_tracks; i++)
-   * {
-   * printf("quicktime_init_hdrl 10 %d %p\n", i, file->riff[0]->hdrl.strl[i]->tag);
-   * }
-   */
 
   /* ODML header */
 
@@ -124,9 +141,8 @@ void quicktime_finalize_hdrl(quicktime_t *file, quicktime_hdrl_t *hdrl)
   for(i = 0; i < file->moov.total_tracks; i++)
     {
     quicktime_trak_t *trak = file->moov.trak[i];
-    quicktime_strl_t *strl = trak->strl;
-
-    quicktime_finalize_strl(file, trak, strl);
+    if(trak->strl)
+      quicktime_finalize_strl(file, trak, trak->strl);
     }
 
   if(file->total_vtracks)
