@@ -1,7 +1,30 @@
-#include <funcprotos.h>
-#include <quicktime/quicktime.h>
+/*******************************************************************************
+ avi_strl.c
 
-#include <string.h> // memcpy
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2010 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
+#include <stdlib.h>
+#include <string.h>
 
 // Update during close:
 // length
@@ -60,9 +83,11 @@ void quicktime_init_strl(quicktime_t *file,
     strl->strh.dwScale = trak->mdia.minf.stbl.stts.table[0].sample_duration;
     /* framerate numerator */
     strl->strh.dwRate  = trak->mdia.mdhd.time_scale;
-    //    strl->strh.dwSuggestedBufferSize = 1024 * 1024;
-    strl->strh.dwQuality = -1;
+    strl->strh.dwQuality = 10000;
     //    strl->strh.dwSampleSize = (int)(trak->tkhd.track_width * trak->tkhd.track_height) * 3;
+    strl->strh.rcFrame.right  = trak->tkhd.track_width;
+    strl->strh.rcFrame.bottom = trak->tkhd.track_height;
+    
     strl->is_video = 1;
     }
   else if(atrack)
@@ -159,14 +184,12 @@ void quicktime_read_strl(quicktime_t *file,
       // Super index.
       // Read the super index + all the partial indexes now
       {
-      //      fprintf(stderr, "quicktime_read_strl got indx\n");
       quicktime_read_indx(file, strl, &leaf_atom);
       strl->have_indx = 1;
       }
     quicktime_atom_skip(file, &leaf_atom);
     } while(quicktime_position(file) < parent_atom->end);
   
-  //printf("quicktime_read_strl 100\n");
   }
 
 
@@ -273,7 +296,6 @@ void quicktime_strl_2_qt(quicktime_t *file,
     else
       bits_per_sample = 8;
     
-    //printf("quicktime_read_strl 20 %d\n", strl->dwScale);
     
     channels       = strl->strf.wf.f.WAVEFORMAT.nChannels;
     sample_rate    = strl->strf.wf.f.WAVEFORMAT.nSamplesPerSec;
@@ -314,7 +336,6 @@ void quicktime_finalize_strl(quicktime_t *file, quicktime_trak_t * trak,
   int64_t old_pos, end_pos;
   /* Rewrite stream headers */
 
-  //  fprintf(stderr, "quicktime_finalize_strl %d\n", file->file_type);
   if(!strl->strh.dwLength)
     strl->strh.dwLength = quicktime_track_samples(file, trak);
   
@@ -351,7 +372,7 @@ void quicktime_finalize_strl(quicktime_t *file, quicktime_trak_t * trak,
 
 void quicktime_strl_dump(quicktime_strl_t *strl)
   {
-  printf("strl\n");
+  lqt_dump("strl\n");
   quicktime_strh_dump(&strl->strh);
 
   if(!strncmp(strl->strh.fccType, "auds", 4))
