@@ -1,32 +1,37 @@
-/*
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as published
- * by the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * 
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- * 
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 
- * USA
- */
+/*******************************************************************************
+ cmodel_yuv420p.c
+
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2010 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
 
 #define HAVE_RGB_16_TO_RGB_24
 #define HAVE_RGB_TO_YUV
 #define HAVE_RGB_TO_YUVJ
 #define HAVE_YUV_TO_RGB
+#define HAVE_YUVJ_TO_RGB
 #define HAVE_YUV_8_TO_YUVJ
 #define HAVE_YUVJ_TO_YUV_8
 
-#include <inttypes.h>
-#include <cmodel_permutation.h>
-#include <lqt.h>
-#include <lqt_funcprotos.h>
-
+#include "lqt_private.h"
+#include "cmodel_permutation.h"
 
 #define TRANSFER_FRAME_DEFAULT(output, \
 	y_in_offset, \
@@ -539,6 +544,14 @@
 						input_v + (v_in_offset)); \
 					TRANSFER_FRAME_TAIL \
 					break; \
+				case BC_RGB161616:      \
+					TRANSFER_YUV422P16_IN_HEAD_16 \
+					transfer_YUV422P16_to_RGB161616((output), \
+						input_y + (y_in_offset), \
+						input_u + (u_in_offset), \
+						input_v + (v_in_offset)); \
+					TRANSFER_FRAME_TAIL \
+					break; \
       				case BC_YUV422P16: \
 					for(i = 0; i < out_h; i++) \
 					{ \
@@ -594,6 +607,14 @@
 						input_v + (v_in_offset)); \
 					TRANSFER_FRAME_TAIL \
 					break; \
+				case BC_RGB161616:      \
+					TRANSFER_YUV444P16_IN_HEAD_16 \
+					transfer_YUV444P16_to_RGB161616((output), \
+						input_y + (y_in_offset), \
+						input_u + (u_in_offset), \
+						input_v + (v_in_offset)); \
+					TRANSFER_FRAME_TAIL \
+					break; \
                                 case BC_YUV444P16:                      \
 					for(i = 0; i < out_h; i++) \
 					{ \
