@@ -1,7 +1,28 @@
-#include <funcprotos.h>
-#include <quicktime/quicktime.h>
-#include <string.h>
+/*******************************************************************************
+ navg.c
 
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2010 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
 
 int quicktime_navg_init(quicktime_navg_t *navg)
 {
@@ -31,21 +52,21 @@ int quicktime_navg_delete(quicktime_navg_t *navg)
 
 void quicktime_navg_dump(quicktime_navg_t *navg)
 {
-	printf("  object parameters (navg)\n");
-	printf("    version %i\n", navg->version);
-	printf("    columns %i\n", navg->columns);
-	printf("    rows %i\n", navg->rows);
-	printf("    loop frames %i\n", navg->loop_frames);
-	printf("    loop frame duration %i\n", navg->loop_dur);
-	printf("    movie type %i\n", navg->movietype);
-	printf("    loop timescale %i\n", navg->loop_timescale);
-	printf("    field of view %f\n", navg->fieldofview);
-	printf("    horizontal start pan %f\n", navg->startHPan);
-	printf("    horizontal end pan %f\n", navg->endHPan);
-	printf("    vertical end pan %f\n", navg->endVPan);
-	printf("    vertical start pan %f\n", navg->startVPan);
-	printf("    initial horizontal pan %f\n", navg->initialHPan);
-	printf("    initial vertical pan %f\n", navg->initialVPan);
+	lqt_dump("  object parameters (navg)\n");
+	lqt_dump("    version %i\n", navg->version);
+	lqt_dump("    columns %i\n", navg->columns);
+	lqt_dump("    rows %i\n", navg->rows);
+	lqt_dump("    loop frames %i\n", navg->loop_frames);
+	lqt_dump("    loop frame duration %i\n", navg->loop_dur);
+	lqt_dump("    movie type %i\n", navg->movietype);
+	lqt_dump("    loop timescale %i\n", navg->loop_timescale);
+	lqt_dump("    field of view %f\n", navg->fieldofview);
+	lqt_dump("    horizontal start pan %f\n", navg->startHPan);
+	lqt_dump("    horizontal end pan %f\n", navg->endHPan);
+	lqt_dump("    vertical end pan %f\n", navg->endVPan);
+	lqt_dump("    vertical start pan %f\n", navg->startVPan);
+	lqt_dump("    initial horizontal pan %f\n", navg->initialHPan);
+	lqt_dump("    initial vertical pan %f\n", navg->initialVPan);
 }
 
 int quicktime_read_navg(quicktime_t *file, quicktime_navg_t *navg, quicktime_atom_t *navg_atom)
