@@ -1,11 +1,37 @@
-#include <funcprotos.h>
-#include <quicktime/quicktime.h>
+/*******************************************************************************
+ tkhd.c
 
-int quicktime_tkhd_init(quicktime_tkhd_t *tkhd)
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2010 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
+
+int quicktime_tkhd_init(quicktime_tkhd_t *tkhd, lqt_file_type_t type)
 {
 	int i;
 	tkhd->version = 0;
-	tkhd->flags = 15;
+        if(IS_MP4(type))
+          tkhd->flags = 7;
+        else
+          tkhd->flags = 15;
         tkhd->creation_time = quicktime_current_time();
 	tkhd->modification_time = quicktime_current_time();
 	tkhd->track_id = 0;
@@ -14,7 +40,7 @@ int quicktime_tkhd_init(quicktime_tkhd_t *tkhd)
 	for(i = 0; i < 8; i++) tkhd->reserved2[i] = 0;
 	tkhd->layer = 0;
 	tkhd->alternate_group = 0;
-	tkhd->volume = 0.996094;
+	tkhd->volume = 1.0;
 	tkhd->reserved3 = 0;
 	quicktime_matrix_init(&(tkhd->matrix));
 	tkhd->track_width = 0;
@@ -29,27 +55,30 @@ int quicktime_tkhd_delete(quicktime_tkhd_t *tkhd)
 
 void quicktime_tkhd_dump(quicktime_tkhd_t *tkhd)
 {
-	printf("  track header\n");
-	printf("   version %d\n", tkhd->version);
-	printf("   flags %ld\n", tkhd->flags);
-	printf("   creation_time %llu\n", tkhd->creation_time);
-	printf("   modification_time %llu\n", tkhd->modification_time);
-	printf("   track_id %d\n", tkhd->track_id);
-	printf("   reserved1 %ld\n", tkhd->reserved1);
-	printf("   duration %lld\n", tkhd->duration);
+	lqt_dump("  track header (tkhd)\n");
+	lqt_dump("   version %d\n", tkhd->version);
+	lqt_dump("   flags %ld\n", tkhd->flags);
+	lqt_dump("    creation_time ");
+        lqt_dump_time(tkhd->creation_time);
+        lqt_dump("\n");
+	lqt_dump("    modification_time ");
+        lqt_dump_time(tkhd->modification_time);
+        lqt_dump("\n");
+	lqt_dump("   track_id %d\n", tkhd->track_id);
+	lqt_dump("   reserved1 %ld\n", tkhd->reserved1);
+	lqt_dump("   duration %"PRId64"\n", tkhd->duration);
 	quicktime_print_chars("   reserved2 ", tkhd->reserved2, 8);
-	printf("   layer %d\n", tkhd->layer);
-	printf("   alternate_group %d\n", tkhd->alternate_group);
-	printf("   volume %f\n", tkhd->volume);
-	printf("   reserved3 %ld\n", tkhd->reserved3);
+	lqt_dump("   layer %d\n", tkhd->layer);
+	lqt_dump("   alternate_group %d\n", tkhd->alternate_group);
+	lqt_dump("   volume %f\n", tkhd->volume);
+	lqt_dump("   reserved3 %ld\n", tkhd->reserved3);
 	quicktime_matrix_dump(&(tkhd->matrix));
-	printf("   track_width %f\n", tkhd->track_width);
-	printf("   track_height %f\n", tkhd->track_height);
+	lqt_dump("   track_width %f\n", tkhd->track_width);
+	lqt_dump("   track_height %f\n", tkhd->track_height);
 }
 
 void quicktime_read_tkhd(quicktime_t *file, quicktime_tkhd_t *tkhd)
 {
-//printf("quicktime_read_tkhd 1 %llx\n", quicktime_position(file));
 	tkhd->version = quicktime_read_char(file);
 	tkhd->flags = quicktime_read_int24(file);
         if(tkhd->version == 0)
@@ -72,9 +101,7 @@ void quicktime_read_tkhd(quicktime_t *file, quicktime_tkhd_t *tkhd)
 	quicktime_read_data(file, tkhd->reserved2, 8);
 	tkhd->layer = quicktime_read_int16(file);
 	tkhd->alternate_group = quicktime_read_int16(file);
-//printf("quicktime_read_tkhd 1 %llx\n", quicktime_position(file));
 	tkhd->volume = quicktime_read_fixed16(file);
-//printf("quicktime_read_tkhd 2\n");
 	tkhd->reserved3 = quicktime_read_int16(file);
 	quicktime_read_matrix(file, &(tkhd->matrix));
 	tkhd->track_width = quicktime_read_fixed32(file);
@@ -124,3 +151,14 @@ void quicktime_tkhd_init_video(quicktime_t *file,
 	tkhd->track_height = frame_h;
 	tkhd->volume = 0;
 }
+
+void quicktime_tkhd_init_timecode(quicktime_t *file,
+                                  quicktime_tkhd_t *tkhd,
+                                  int frame_w,
+                                  int frame_h)
+  {
+  tkhd->track_width = frame_w;
+  tkhd->track_height = 20;
+  tkhd->matrix.values[7] = frame_h;
+  tkhd->volume = 0;
+  }
